==> pyphant.imageprocessing-0.8a2.tar.gz: pyphant.imageprocessing-0.8a2/ImageProcessing/DiffWorker.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2009, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
The Diff Worker belongs to Pyphant's Image Processing Toolbox. It
computes the difference between two images, eg. the skeletonised image
and the origial image.
"""

__id__ = "$Id$"
__author__ = "$Author$"
__version__ = "$Revision$"
# $Source$

from pyphant.core import (Worker, Connectors)
import copy, numpy

class DiffWorker(Worker.Worker):
    API = 2
    VERSION = 2
    REVISION = "$Revision$"[11:-1]
    name=u"Diff Worker"
    _params = [("absolute", u"Return absolute of difference: ", [u"Yes", u"No"], None),
               ("longname",u"Name of result",'default',None),
               ("symbol",u"Symbol of result",'default',None)]
    
    _sockets = [ ("image1", Connectors.TYPE_IMAGE),
                 ("image2", Connectors.TYPE_IMAGE)]

    @Worker.plug(Connectors.TYPE_IMAGE)
    def diffImages(self, image1, image2, subscriber=0):
        result = image1 - image2
        if self.paramAbsolute.value==u"Yes":
            result.data = numpy.abs(result.data)
        if self.paramLongname.value != 'default':
            result.longname = self.paramLongname.value
        if self.paramSymbol.value != 'default':
            result.shortname = self.paramSymbol.value
        result.seal()
        return result

==> pyphant.imageprocessing-1.0b1.tar.gz: pyphant.imageprocessing-1.0b1/ImageProcessing/DiffWorker.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2009, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
The Diff Worker belongs to Pyphant's Image Processing Toolbox. It
computes the difference between two images, eg. the skeletonised image
and the origial image.
"""

__id__ = "$Id$"
__author__ = "$Author$"
__version__ = "$Revision$"
# $Source$

from pyphant.core import (Worker, Connectors)


class DiffWorker(Worker.Worker):
    API = 2
    VERSION = 2
    REVISION = "$Revision$"[11:-1]
    name = "Difference"
    _params = [("absolute", u"Return absolute of difference: ",
                [u"Yes", u"No"], None),
               ("longname", u"Name of result", 'default', None),
               ("symbol", u"Symbol of result", 'default', None)]
    _sockets = [ ("image1", Connectors.TYPE_IMAGE),
                 ("image2", Connectors.TYPE_IMAGE)]

    @Worker.plug(Connectors.TYPE_IMAGE)
    def diffImages(self, image1, image2, subscriber=0):
        result = image1 - image2
        if self.paramAbsolute.value == u"Yes":
            import numpy
            result.data = numpy.abs(result.data)
        if self.paramLongname.value != 'default':
            result.longname = self.paramLongname.value
        if self.paramSymbol.value != 'default':
            result.shortname = self.paramSymbol.value
        result.seal()
        return result
